/**
 * Copyright 2019 Greg Whitaker
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package praxis.service.controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;
import praxis.service.controller.model.GetEventResponse;
import praxis.service.service.event.EventService;
import reactor.core.publisher.Mono;

@RestController
public class EventController {

    @Autowired
    private EventService eventService;

    @GetMapping("/events/{eventId}")
    public Mono<ResponseEntity<GetEventResponse>> getEvent(@PathVariable("eventId") String eventId) {
        return eventService.getEvent(eventId)
                .map(event -> ResponseEntity.ok(GetEventResponse.from(event)))
                .switchIfEmpty(Mono.fromSupplier(() -> ResponseEntity.notFound().build()));
    }
}
